@@ -144,9 +144,11 @@ if ($do==1) {
          "/featureName:IIS-LegacySnapIn",'__display__');
       my $appcmd="$ENV{WINDIR}/SYSTEM32/inetsrv";
       ($appcmd,$stderr)=$handle->cmd("cygpath -u $appcmd");
-      my $cygloc=$handle->cmd("cygpath -w ~");
-      $cygloc.="\\FullAutoAPI";
-      $cygloc=~s/\\/\\\\/g;
+      my $cyglocb=$handle->cmd("cygpath -w /");
+      my $cyglocw=$handle->cmd("cygpath -w ~");
+      my $cyglocwf="$cyglocw\\FullAutoAPI";
+      $cyglocw=~s/\\/\\\\/g;
+      $cyglocwf=~s/\\/\\\\/g;
       ($stdout,$stderr)=$handle->cwd($appcmd);
       ($stdout,$stderr)=$handle->cmd("pwd",'__display__');
       my $sleep=0;
@@ -157,25 +159,34 @@ if ($do==1) {
         last if $sleep++>300;
       }
       ($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
-         "/id:2 /physicalPath:$cygloc\\root /bindings:http/*:5000",
+         "/id:2 /physicalPath:$cyglocwf\\root /bindings:http/*:4000",
          '__display__');
       ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
-         "system.webServer/fastCgi /+[\"fullpath=\'$cygloc\\script\\".
-         "CGI_script\',arguments=\'$cygloc\\script\\fullautoapi_fastcgi.pl ".
-         "-e\',maxInstances=\'4\',idleTimeout=\'300\',activityTimeout=\'30\',".
-         "requestTimeout='\90\',instanceMaxRequests=\'1000\',protocol=".
-         "\'NamedPipe\',flushNamedPipe=\'False\']\" /commit:apphost",
-         '__display__');
+         "system.webServer/fastCgi /+[\"fullpath=\'$cyglocb\\script\\".
+         "CGI_script.bat\',arguments=\'$cyglocwf\\script\\".
+         "fullautoapi_fastcgi.pl -e\',maxInstances=\'4\',".
+         "idleTimeout=\'300\',activityTimeout=\'30\',requestTimeout='\90\',".
+         "instanceMaxRequests=\'1000\',protocol=\'NamedPipe\',".
+         "flushNamedPipe=\'False\']\" /commit:apphost",'__display__');
       ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
          "system.webServer/handlers /+\"[name=\'FullAutoAPI\',".
          "path=\'*\',verb=\'GET,HEAD,POST\',modules=".
-         "\'FastCgiModule\',scriptProcessor=\'$cygloc\\script\\".
-         "CGI_Script|$cygloc\\script\\fullautoapi_fastcgi.pl -e\',". 
+         "\'FastCgiModule\',scriptProcessor=\'$cyglocb\\script\\".
+         "CGI_Script.bat|$cyglocwf\\script\\fullautoapi_fastcgi.pl -e\',".
          "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
          "/commit:apphost",'__display__');
-      ($stdout,$stderr)=$handle->cwd("~");
-      ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/script",'__display__');
-      ($stdout,$stderr)=$handle->cwd("~/FullAutoAPI/script");
+      ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
+         "system.serviceModel/serviceHostingEnvironment ".
+         "/+\"[multipleSiteBindingsEnabled=\'true\']\" ".
+         "/commit:apphost",'__display__');
+      ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
+      ($stdout,$stderr)=$handle->cmd("touch CGI_Script.bat",'__display__');
+      $cyglocb=~s/\\/\\x5C/g;
+      my $content=<<END;
+$cyglocb\\x5Cbin\\x5Cbash -lc \\x22/bin/perl \\x251 \\x252\\x22
+END
+      ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
+      ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("touch CGI_Script");
       #
       # echo-ing/streaming files over ssh can be tricky. Use echo -e
@@ -189,12 +200,11 @@ if ($do==1) {
       #          $  -   \\x24
       #
       my $content=<<END;
-#\\x21/bin/sh
-cd bin
-/bin/perl -wT \\x241
+$cyglocb\\bin\\bash -lc \\x22/bin/perl -e \\\\x22\\x241\\\\x24\\x24
 END
-      ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script");
+      ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
       ($stdout,$stderr)=$handle->cwd("~");
+      #($stdout,$stderr)=$handle->cmd("iisreset /start",'__display__');
    }
    ###############
    ## RABBITMQ
@@ -1381,7 +1391,7 @@ END
       "./script/fullautoapi_create.pl controller User",'__display__');
    ($stdout,$stderr)=$handle->cmd("mv lib/FullAutoAPI/Controller/User.pm ".
       "lib/FullAutoAPI/Controller/User.bak");
-   my $view_path='./lib/FullAutoAPI/View/TT.pm';
+   my $view_path='./FullAutoAPI/View/TT.pm';
    ($stdout,$stderr)=$handle->cmd(
       "./script/fullautoapi_create.pl view TT TT",'__display__');
    $ad='    WRAPPER => %SQ%wrapper.tt%SQ%,%NL%';
